@@ -28,6 +28,7 @@ def CalculateHash(block, part_of_blocks_hash, the_blocks_hash, the_accounts):
     main_list = [
         block.previous_hash,
         str(block.sequance_number),
+        str(block.empty_block_number),
         blocks_hash,
         accounts_hash,
         tx_hash,
@@ -38,7 +39,4 @@ def CalculateHash(block, part_of_blocks_hash, the_blocks_hash, the_accounts):
 
     the_hash = MerkleTree(main_list).getRootHash()
 
-    # Setting The Hashes
-    block.hash = the_hash
-
     return the_hash
